==> yunke-wps-1.0.2.tgz: package/index.js <==
/* eslint-disable no-unused-vars */
import * as WPS from "./sdk/web-office-sdk-v1.1.8.es.js";
var wpsInstance = null;
var fileType = null;
var toCallback = null;
var newInfo = null;

export function openWps(type, url, token, slide, clickCount, callback = null) {
	toCallback = callback;
	fileType = type;
	wpsInstance = WPS.config({
		mode: "simple",
		mount: document.getElementById("wps"),
		wpsUrl: url,
		commonOptions: {
			// 隐藏顶部区域(头部和工具栏)
			isShowTopArea: false,
			// 隐藏头部区域,
			isShowHeader: false,
			isBrowserViewFullscreen: true,
			isIframeViewFullscreen: true,
		},
		ptOptions: {
			isShowBottomStatusBar: false,
			isOpenIntoEdit: false,
		},
		commandBars: [
			{
				cmbId: "PlayComponentToolbar",
				attributes: {
					visible: false,
					enable: false,
				},
			},
			{
				cmbId: "HistoryVersionDivider",
				attributes: {
					visible: false,
					enable: false,
				},
			},
		],
	});
	wpsInstance.setToken({ token: token });
	wpsInstance.ready().then(() => {
		wpsInstance.PPTApplication().ActivePresentation.View.ZoomToFit = -1;
		// screen.orientation.angle = 90;
		if (type === "ppt" || type === "pptx") {
			pptStart(slide, clickCount);
			// setTimeout(function(){document.getElementById("office-iframe").contentWindow.document.getElementById("workspace_wrapper").style=""},3000)
		}

		if (type === "doc" || type === "docx") {
			wordStart(slide);
			// setTimeout(function(){document.getElementById("office-iframe").contentWindow.document.getElementById("workspace_wrapper").style=""},3000)
		}
	});
}

// 初始化未完成，消息更新
export function updateStartInfo(info) {
	newInfo = info;
}

export function pptMoveStep(slide, clickCount, domIndex) {
	console.log("pptMoveStep:" + slide + ",clickCount:" + clickCount);
	pptGotoPage(slide);
	jumpClick(clickCount + 1);
}

export function pptGotoPage(slide) {
	console.log("pptGotoPage:" + slide);
	wpsInstance.PPTApplication().ActivePresentation.SlideShowWindow.View.GotoSlide(slide, 0);
}
// 获取当前ppt页码&动画步数
async function currentInfo(title) {
	const wps = await wpsInstance.PPTApplication().ActivePresentation;
	const currentSlide = await wps.SlideShowWindow.View.Slide.SlideIndex;
	const currentClickCount = await wps.SlideShowWindow.View.GetClickIndex();
	const totalSlide = await wps.Slides.Count;
	return {
		title: title,
		slideInfo: {
			currentSlide: currentSlide,
			currentClickCount: currentClickCount,
			totalSlide: totalSlide,
		},
	};
}

// PPT下一步动画
export function nextClick() {
	console.log("nextClick");
	wpsInstance.PPTApplication().ActivePresentation.SlideShowWindow.View.GotoNextClick();
}

// PPT上一步动画
export function preClick() {
	console.log("preClick");
	wpsInstance.PPTApplication().ActivePresentation.SlideShowWindow.View.GotoPreClick();
}

// PPT跳转到指定动画
export function jumpClick(number) {
	// number 从1开始"
	console.log("jumpClick:", number);
	wpsInstance.Application.ActivePresentation.SlideShowWindow.View.GotoClick(number);
}

// 当前页动画总步数
export async function getCurrentClickCount() {
	const clickCount = await wpsInstance.PPTApplication().ActivePresentation.SlideShowWindow.View.GetClickCount();
	console.log("当前页动画总步数(-1表示总步数为0):", clickCount);

	return clickCount;
}

function pptStart(slide, clickCount) {
	const afterRun = wpsInstance.PPTApplication().ActivePresentation.SlideShowSettings.Run();
	afterRun.then(async () => {
		if (newInfo) {
			const { currentSlide, currentClickCount } = newInfo;
			if (currentSlide !== undefined) {
				slide = currentSlide;
			}
			if (currentClickCount !== undefined) {
				clickCount = currentClickCount;
			}
			newInfo = null;
		}
		console.log("pptStart:" + slide + ",clickCount:" + clickCount);
		await wpsInstance.PPTApplication().ActivePresentation.SlideShowWindow.View.Play(slide, clickCount);
		const param = await currentInfo("ready-dom");
		if (toCallback) {
			toCallback(param);
		}
	});
	// 幻灯片动画下一步
	wpsInstance.PPTApplication().Sub.SlideShowOnNext = async () => {
		const param = await currentInfo("clickCountNext");
		if (toCallback) {
			toCallback(param);
		}
	};
	// 幻灯片动画上一步
	wpsInstance.PPTApplication().Sub.SlideShowOnPrevious = async () => {
		const param = await currentInfo("clickCountPre");
		if (toCallback) {
			toCallback(param);
		}
	};
	// 当前页改变事件
	wpsInstance.PPTApplication().Sub.SlideSelectionChanged = async () => {
		const param = await currentInfo("changePage");
		if (toCallback) {
			toCallback(param);
		}
	};
}

function wordStart(slide) {
	console.log("wordStart:" + slide);
	// 将当前文档的状态切换成分页模式
	const afterSwitch = wpsInstance.WordApplication().ActiveDocument.SwitchTypoMode(false);
	afterSwitch.then(() => {
		// 文档窗口大小进行调整后使页面以最佳尺寸适应活动窗口
		wpsInstance.WordApplication().ActiveDocument.ActiveWindow.View.Zoom.PageFit = 2;
		// 隐藏目录
		wpsInstance.WordApplication().ActiveDocument.ActiveWindow.DocumentMap = false;
	});
}

==> yunke-wps-1.0.7.tgz: package/index.js <==
/* eslint-disable no-unused-vars */
import WPS from "./lib";
export default WPS;
var wpsInstance = null;
var fileType = null;
var toCallback = null;
var newInfo = null;

export function openWps(type, url, token, slide, clickCount, callback = null) {
	console.log("wps-sdk-v1.1.11");
	toCallback = callback;
	fileType = type;
	wpsInstance = WPS.config({
		mode: "simple",
		mount: document.getElementById("wps"),
		wpsUrl: url,
		commonOptions: {
			// 隐藏顶部区域(头部和工具栏)
			isShowTopArea: false,
			// 隐藏头部区域,
			isShowHeader: false,
			isBrowserViewFullscreen: true,
			isIframeViewFullscreen: true,
		},
		pptOptions: {
			isShowBottomStatusBar: false, // 是否展示底部状态栏
			isShowRemarkView: false, // 是否显示备注视图
			isShowInsertMedia: false, // 是否显示插入音视频入口
			isShowComment: false, // 是否显示评论相关入口
			mobile: {
				isOpenIntoEdit: false, // （Mobile）要有编辑权限，移动端打开时是否进入编辑
				showPrevTipWhilePlay: false, // （Mobile）播放时向上翻页，是否展示 “上一页” 的提示
				isShowReviewLogo: false, // （Mobile）是否显示审阅左上 logo
			},
		},
		ptOptions: {
			isShowBottomStatusBar: false,
			isOpenIntoEdit: false,
		},
		commandBars: [
			{
				cmbId: "PlayComponentToolbar",
				attributes: {
					visible: false,
					enable: false,
				},
			},
			{
				cmbId: "HistoryVersionDivider",
				attributes: {
					visible: false,
					enable: false,
				},
			},
		],
	});
	wpsInstance.setToken({ token: token });
	wpsInstance.ready().then(() => {
		setZoomFit(-1);
		// screen.orientation.angle = 90;
		if (type === "ppt" || type === "pptx") {
			pptStart(slide, clickCount);
			// setTimeout(function(){document.getElementById("office-iframe").contentWindow.document.getElementById("workspace_wrapper").style=""},3000)
		}

		if (type === "doc" || type === "docx") {
			wordStart(slide);
			// setTimeout(function(){document.getElementById("office-iframe").contentWindow.document.getElementById("workspace_wrapper").style=""},3000)
		}
	});
}

// 初始化未完成，消息更新
export function updateStartInfo(info) {
	newInfo = info;
}

export function pptMoveStep(slide, clickCount, domIndex) {
	console.log("pptMoveStep:" + slide + ",clickCount:" + clickCount);
	pptGotoPage(slide);
	jumpClick(clickCount + 1);
}

export function pptGotoPage(slide) {
	console.log("pptGotoPage:" + slide);
	wpsInstance.PPTApplication().ActivePresentation.SlideShowWindow.View.GotoSlide(slide, 0);
}
// 获取当前ppt页码&动画步数
async function currentInfo(title) {
	const wps = await wpsInstance.PPTApplication().ActivePresentation;
	const currentSlide = await wps.SlideShowWindow.View.Slide.SlideIndex;
	const currentClickCount = await wps.SlideShowWindow.View.GetClickIndex();
	const totalSlide = await wps.Slides.Count;
	const totalCurrentClickCount = await getCurrentClickCount();
	return {
		title: title,
		slideInfo: {
			currentSlide: currentSlide,
			currentClickCount: currentClickCount,
			totalSlide: totalSlide,
			totalCurrentClickCount: totalCurrentClickCount,
		},
	};
}

// PPT下一步动画
export function nextClick() {
	console.log("nextClick");
	wpsInstance.PPTApplication().ActivePresentation.SlideShowWindow.View.GotoNextClick();
}

// PPT上一步动画
export function preClick() {
	console.log("preClick");
	wpsInstance.PPTApplication().ActivePresentation.SlideShowWindow.View.GotoPreClick();
}

// PPT跳转到指定动画
export function jumpClick(number) {
	// number 从1开始"
	console.log("jumpClick:", number);
	wpsInstance.Application.ActivePresentation.SlideShowWindow.View.GotoClick(number);
}

// 当前页动画总步数
export async function getCurrentClickCount() {
	const clickCount = await wpsInstance.PPTApplication().ActivePresentation.SlideShowWindow.View.GetClickCount();
	console.log("当前页动画总步数(-1表示总步数为0):", clickCount);

	return clickCount;
}

// 设置缩放比例
export function setZoomFit(value) {
	if (wpsInstance) {
		wpsInstance.PPTApplication().ActivePresentation.View.ZoomToFit = value;
		console.log(`setZoomFit(${value})`);
	}
}

function pptStart(slide, clickCount) {
	const afterRun = wpsInstance.PPTApplication().ActivePresentation.SlideShowSettings.Run();
	afterRun.then(async () => {
		if (newInfo) {
			const { currentSlide, currentClickCount } = newInfo;
			if (currentSlide !== undefined) {
				slide = currentSlide;
			}
			if (currentClickCount !== undefined) {
				clickCount = currentClickCount;
			}
			newInfo = null;
		}
		console.log("pptStart:" + slide + ",clickCount:" + clickCount);
		await wpsInstance.PPTApplication().ActivePresentation.SlideShowWindow.View.Play(slide, clickCount);
		const param = await currentInfo("ready-dom");
		if (toCallback) {
			toCallback(param);
		}
	});
	// 幻灯片动画下一步
	wpsInstance.PPTApplication().Sub.SlideShowOnNext = async () => {
		console.log("SlideShowOnNext:幻灯片下一步动画回调");
		const param = await currentInfo("clickCountNext");
		if (toCallback) {
			toCallback(param);
		}
	};
	// 幻灯片动画上一步
	wpsInstance.PPTApplication().Sub.SlideShowOnPrevious = async () => {
		console.log("SlideShowOnPrevious:幻灯片上一步动画回调");
		const param = await currentInfo("clickCountPre");
		if (toCallback) {
			toCallback(param);
		}
	};
	// 当前页改变事件
	wpsInstance.PPTApplication().Sub.SlideSelectionChanged = async () => {
		console.log("SlideSelectionChanged:当前页改变事件回调");
		const param = await currentInfo("changePage");
		if (toCallback) {
			toCallback(param);
		}
	};
}

function wordStart(slide) {
	console.log("wordStart:" + slide);
	// 将当前文档的状态切换成分页模式
	const afterSwitch = wpsInstance.WordApplication().ActiveDocument.SwitchTypoMode(false);
	afterSwitch.then(() => {
		// 文档窗口大小进行调整后使页面以最佳尺寸适应活动窗口
		wpsInstance.WordApplication().ActiveDocument.ActiveWindow.View.Zoom.PageFit = 2;
		// 隐藏目录
		wpsInstance.WordApplication().ActiveDocument.ActiveWindow.DocumentMap = false;
	});
}

// 消息回调函数获取当前信息
export async function callbackCurrentInfo() {
	console.log("回调获取当前信息：");
	if (toCallback) {
		const param = await currentInfo("callbackCurrentInfo");
		toCallback(param);
	}
}
